<?php

/**
 * @file
 * Displays Phylotree widget.
 *
 * Available variables:
 * - $newick_url: URL to the newick file.
 * - $tree_id: tree display unique identifier on the page.
 * - $focus: one or more name/label of the node(s) to focus on.
 */
?>

<div id="<?php echo $tree_id;?>_container" class="phylotree-block-container">
  <div id="<?php echo $tree_id;?>_toolbar" class="phylotree-toolbar"></div>
  <div id="<?php echo $tree_id;?>_display_wrapper" class="phylotree-display-wrapper">
    <svg id="<?php echo $tree_id;?>_display" class="phylotree-display"></svg>
  </div>
</div>

<script>
jQuery(function() {
  var $ = jQuery;

  // Setup tree layout.
  var tree = d3.layout.phylotree('#<?php echo $tree_id;?>_container')
    .options({
      'brush': false,
      'zoom': true,
      'left-right-spacing': 'fit-to-size',
      'show-scale': false
    })
    .css_classes({'tree-container': '<?php echo $tree_id;?>-container'})
    .svg(d3.select('#<?php echo $tree_id;?>_display'))
  ;
  tree.size(Drupal.phylotree.get_render_size(tree));

  // Add toolbar buttons.
  Drupal.phylotree.append_branch_filter_widget(
    '#<?php echo $tree_id;?>_toolbar',
    '<?php echo $tree_id;?>',
    tree
  );
  Drupal.phylotree.append_vertical_expand_widgets(
    '#<?php echo $tree_id;?>_toolbar',
    '<?php echo $tree_id;?>',
    tree
  );
  Drupal.phylotree.append_horizontal_expand_widgets(
    '#<?php echo $tree_id;?>_toolbar',
    '<?php echo $tree_id;?>',
    tree
  );
  Drupal.phylotree.append_branch_sorter_widgets(
    '#<?php echo $tree_id;?>_toolbar',
    '<?php echo $tree_id;?>',
    tree
  );

  Drupal.phylotree.append_align_toggler_widget(
    '#<?php echo $tree_id;?>_toolbar',
    '<?php echo $tree_id;?>',
    tree
  );

  Drupal.phylotree.append_layout_selection_widget(
    '#<?php echo $tree_id;?>_toolbar',
    '<?php echo $tree_id;?>',
    tree
  );

  // Load tree.
  $.ajax({
    url: '<?php echo $newick_url; ?>',
    dataType: 'text',
    success: function (data) {
      tree(data).layout();
<?php
  if (!empty($focus)) {
    if (is_array($focus)) {
?>
      var node;
<?php
      foreach ($focus as $focussed_node) {
?>
      node = tree.get_node_by_name('<?php echo $focussed_node; ?>');
      tree.modify_selection(tree.path_to_root(node));
<?php
      }
    }
    else {
?>
      var node = tree.get_node_by_name('<?php echo $focus; ?>');
      tree.modify_selection(tree.path_to_root(node));
<?php
    }
  }
?>
    }
  });
});

</script>
